summaryrefslogtreecommitdiffstats
path: root/buildtools/lib/parsers/autotools/autotoolsast.h
diff options
context:
space:
mode:
Diffstat (limited to 'buildtools/lib/parsers/autotools/autotoolsast.h')
-rw-r--r--buildtools/lib/parsers/autotools/autotoolsast.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/buildtools/lib/parsers/autotools/autotoolsast.h b/buildtools/lib/parsers/autotools/autotoolsast.h
index 768e3e07..e690baa4 100644
--- a/buildtools/lib/parsers/autotools/autotoolsast.h
+++ b/buildtools/lib/parsers/autotools/autotoolsast.h
@@ -37,7 +37,7 @@ namespace AutoTools
* AST node.
* This is the base class. Objects of this type are not created by the parser.
*
* Each AST node holds the list of its children which are always deleted in the
* destructor. This way, it's possible call delete for only root AST node and
* others will be deleted automatically.
*
@@ -85,20 +85,20 @@ public:
/** @return The indentation string based on node depth.*/
virtual TQString indentation();
//! \return true if this AST has children
bool hasChildren() const;
/**
* Get the children of this ast
* \return the list of this ast's childre
*/
- TQValueList<AST*> children() const;
+ TQValueList<AST*> tqchildren() const;
protected:
NodeType m_nodeType;
- TQValueList<AST*> m_children;
+ TQValueList<AST*> m_tqchildren;
private:
int m_depth;
@@ -37,7 +37,7 @@ namespace AutoTools
* This is the base class. Objects of this type are not created by the parser.
*
- * Each AST node holds the list of its children which are always deleted in the
+ * Each AST node holds the list of its tqchildren which are always deleted in the
* destructor. This way, it's possible call delete for only root AST node and
* others will be deleted automatically.
@@ -85,20 +85,20 @@ public:
/** @return The indentation string based on node depth.*/
virtual TQString indentation();
- //! \return true if this AST has children
+ //! \return true if this AST has tqchildren
bool hasChildren() const;
/**
@@ -85,20 +85,20 @@ public:
bool hasChildren() const;
/**
- * Get the children of this ast
+ * Get the tqchildren of this ast
* \return the list of this ast's childre
*/